==> plf-community-sources-1.3.3.zip: platform-sources-1.3.3/social-6.3.3/component/core/src/main/java/org/exoplatform/social/core/listeners/MetadataItemDeleted.java <==
/*
 * This file is part of the Meeds project (https://meeds.io/).
 * Copyright (C) 2020 - 2022 Meeds Association contact@meeds.io
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
package org.exoplatform.social.core.listeners;

import org.exoplatform.commons.search.index.IndexingService;
import org.exoplatform.services.listener.Event;
import org.exoplatform.social.core.storage.api.ActivityStorage;
import org.exoplatform.social.metadata.MetadataService;
import org.exoplatform.social.metadata.model.MetadataItem;

public class MetadataItemDeleted extends AbstractMetadataItemListener<Long, MetadataItem> {

  public MetadataItemDeleted(MetadataService metadataService, ActivityStorage activityStorage, IndexingService indexingService) {
    super(metadataService, activityStorage, indexingService);
  }

  @Override
  public void onEvent(Event<Long, MetadataItem> event) throws Exception {
    // If the modified metadata concerns an 'activity'
    MetadataItem metadataItem = event.getData();
    String objectType = event.getData().getObjectType();
    String objectId = metadataItem.getObjectId();
    handleMetadataModification(objectType, objectId);
  }

}

==> plf-community-sources-1.4.0.zip: platform-sources-1.4.0/social-6.4.0/component/core/src/main/java/org/exoplatform/social/core/listeners/MetadataItemDeleted.java <==
/*
 * This file is part of the Meeds project (https://meeds.io/).
 * Copyright (C) 2020 - 2022 Meeds Association contact@meeds.io
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
package org.exoplatform.social.core.listeners;

import org.exoplatform.commons.search.index.IndexingService;
import org.exoplatform.services.listener.Event;
import org.exoplatform.social.core.storage.api.ActivityStorage;
import org.exoplatform.social.core.storage.api.SpaceStorage;
import org.exoplatform.social.metadata.MetadataService;
import org.exoplatform.social.metadata.model.MetadataItem;

public class MetadataItemDeleted extends AbstractMetadataItemListener<Long, MetadataItem> {

  public MetadataItemDeleted(MetadataService metadataService,
                             ActivityStorage activityStorage,
                             SpaceStorage spaceStorage,
                             IndexingService indexingService) {
    super(metadataService, activityStorage, spaceStorage, indexingService);
  }

  @Override
  public void onEvent(Event<Long, MetadataItem> event) throws Exception {
    // If the modified metadata concerns an 'activity'
    MetadataItem metadataItem = event.getData();
    String objectType = event.getData().getObjectType();
    String objectId = metadataItem.getObjectId();
    handleMetadataModification(objectType, objectId);
  }

}
